require "katar/globals"
require "katar/version"
require "thor"

module Katar
    module Commands
        class Application < Thor

            desc "version", "Show Katar version number"
            def version
                puts Katar::VERSION
            end

            desc "init", "Create a stub Katar.yaml file"
            def init
                require_command!("init_command")
            end

            desc "edit", "Edit the Katar.yaml file"
            def edit
                require_command!("edit_command")
            end

            desc "up", "Start the Katar machine"
            def up
                run_command "vagrant up"
            end 

            desc "ssh", "Login to the Katar machine via SSH"
            def ssh
                run_command "vagrant ssh"
            end

            desc "suspend", "Suspend the Katar machine"
            def suspend
                run_command "vagrant suspend"
            end

            desc "resume", "Resume the suspended Katar machine"
            def resume
                run_command "vagrant resume"
            end

            desc "reload", "Reload the Katar machine image"
            def reload
                run_command "vagrant reload"
            end

            desc "destroy", "Destroy the Katar machine"
            def destroy
                run_command "vagrant destroy"
            end

            desc "status", "Get the status of the Katar machine"
            def status
                run_command "vagrant status"
            end

            desc "halt", "Halt the Katar machine"
            def halt
                run_command "vagrant halt"
            end

            desc "provision", "Re-provisions the Katar machine"
            def provision
                run_command "vagrant provision"
            end

            desc "update", "Update the Katar machine image"
            def update
                run_command "vagrant box update"
            end

        private

            def run_command(command)
                Dir.chdir(  File.join(File.dirname(__FILE__), '../../../')  ){
                    exec command
                }
            end

            def require_command!(command)
                require "katar/commands/#{command}"
            end

        end
    end
end